@@ -9,51 +9,154 @@ use Math::Cephes qw(:utils);
 use Contextual::Return;
 use Perl6::Form;
 use Statistics::Distributions qw( fprob fdistr);
-#use vars qw($VERSION);
 
-#use version; $VERSION = qv('0.0.3');
-our $VERSION = '0.03.01';
+=head1 NAME
+
+Statistics::Distributions::Ancova - Perl implementation of One-Way Analysis of Covariance for Independent Samples.
+
+=cut
+=head1 VERSION
+
+This document describes Statistics::Distributions::Ancova version 0.32.0.
+
+=cut
+use version; our $VERSION = qv('0.32.0'); 
+=head1 SYNOPSIS
+
+    use Statistics::Distributions::Ancova;
+
+    # Create an Ancova object and set significance value of p = 0.05 for statistical test. See METHODS for optional named arguments and default values.
+    my $anc = Statistics::Distributions::Ancova->new ( { significance => 0.005, input_verbosity => 1, output_verbosity => 1 } );
+
+    # Example using k=3 groups. Data includes our dependent variable of interest (Y) and covariant data (X) that is used to eliminate obscuring effects of covariance.
+    my @Drug_A_Y =  ('29','27','31','33','32','24','16');
+    my @Drug_A_X = ('53','64','55','67','55','45','35');
+    my @Drug_B_Y = ('39','34','20','35','57','28','32','17');
+    my @Drug_B_X = ('24','19','13','18','25','16','16','13');
+    my @Drug_C_Y = ('12','21','26','17','25','9','12');
+    my @Drug_C_X = ('5','12','12','9','12','3','3');
+
+    # Data is sent to object as nested HASH reference. Individual group names are option, but to distinguish IV/DV, the names Y and X for the variables are compulsory.
+    my $h_ref = { 'group_A' =>  {
+                                    Y => \@Drug_A_Y,
+                                    X => \@Drug_A_X,
+                            }, 
+                'group_B' =>  { 
+                                    Y => \@Drug_B_Y,
+                                    X => \@Drug_B_X,
+                            }, 
+                'group_C' =>  { 
+                                    Y => \@Drug_C_Y,
+                                    X => \@Drug_C_X,
+                            }, 
+                };
+
+    # Feed the object the data pass data HASH reference with named argument 'data'.
+    $anc->load_data ( { data => $h_ref } );
+
+    # Perform analysis
+    $anc->ancova_analysis;
+
+    # To access results use results method. The return of this method is context dependent (see METHODS). 
+    # To print a report to STDOUT call results in VOID context.
+    $anc->results();
+
+=cut
+=head1 DESCRIPTION
+
+ANCOVA is a merger of ANOVA and regression for continuous variables. As with paired t-test and repeated-measures ANOVA 
+this test removes the obscuring effects of pre-existing individual differences among subjects and thus may increase
+statistical power. In cases where a substantial portion of the variability that occurs within each of the set of a dependent variable Y is 
+actually covariance with another concomitant variable X measures, this test removes the covariance with X from Y thus 
+removing a portion of the irrelevant variability of individual differences. See http://en.wikipedia.org/wiki/Analysis_of_covariance for more info.
+
+=cut
+=head1 Methods
+
+=cut
+
+#######################################################################################################################
 
 sub new {
-    #my ($class, $significance ) = @_;
-    
     my ($class, $args_h_ref ) = @_;
     croak qq{\nArguments must be passed as HASH reference.} if ( ( $args_h_ref ) && ( ref $args_h_ref ne q{HASH} ) );
 
     my $self = {};
     bless $self, $class;
    
-    #$self->set_significance($significance);
-    $self->set_significance($args_h_ref);
-
-    $self->set_verbosity($args_h_ref);
+    $self->_set_significance($args_h_ref);
+    $self->_set_verbosity($args_h_ref);
 
     return $self;
 }
+=head2 new
 
-sub set_significance {
+Creates new Statistics::Distributions::Ancova object. Without arguments defaults to a significance test value of p = 0.05.
     
-    #my ($self, $sig ) = @_;
-    #$sig ||= q{.05};
+    my $anc = Statistics::Distributions::Ancova->new ();
+
+# Use significance option to set the significance level for the test to values other than 0.05.
     
+    my $anc = Statistics::Distributions::Ancova->new ( { significance => 0.005 } );
+
+# To prin data-checking step messages (upon data loading with C<load_data>) to STDOUT set input_verbosity to 1.     
+
+    my $anc = Statistics::Distributions::Ancova->new ( { input_verbosity => 1 } );
+
+# To print a detailed report when C<result> method is called in VOID context to STDOUT set output_verbosity to 1.     
+
+    my $anc = Statistics::Distributions::Ancova->new ( { output_verbosity => 1 } );
+
+=cut
+
+#/ now made this private 
+sub _set_significance {
     my ($self, $args_h_ref) = @_;
 
     croak qq{\nArguments must be passed as HASH reference.} if ( ( $args_h_ref ) && ( ref $args_h_ref ne q{HASH} ) );
     if (!exists $args_h_ref->{significance}) { print qq{\n\nFalling back on default 0.05 significance value.\n} }
     my $sig = exists $args_h_ref->{significance} ? $args_h_ref->{significance} : q{0.05}; 
 
-    # check arguement passed
-    croak qq{\nThe p value must be numeric and in the range > 0 and < 1.} if ( $sig !~ /\A[01]?\.\d{1,7}\z/xms || $sig <= 0 || $sig >= 1) ; 
+    # included exponential number check
+    croak qq{\nThe p value must be numeric and in the range > 0 and < 1.} if ( $sig !~ /\A \d* \.? \d+ ([eE][+-]?\d+)? \z/xms || $sig <= 0 || $sig >= 1) ; 
+    #croak qq{\nThe p value must be numeric and in the range > 0 and < 1.} if ( $sig !~ /\A \d{1,7} \.? \d+ ([eE][+-]?\d+)? \z/xms || $sig <= 0 || $sig >= 1) ; 
     
     $self->{significance} = $sig;
     return;
 }
 
-sub set_verbosity {
-    
-    #my ($self, $sig ) = @_;
-    #$sig ||= q{.05};
+sub set_significance {
+
+    my ( $self, $sig ) = @_;
+    #/ in this case we must distinguish between 0 and no arugement!
+    #y the 0 detector
+    croak qq{\nThe p value cannot be 0.} if ( defined $sig && $sig == 0 ) ; 
+    #y the no arg detector/empty string - already forced numeric
+    $sig || print qq{\n\nFalling back on default 0.05 significance value.\n};
+    $sig ||= 0.05;
+    #y no need to check for 0 again
+    #/ we don´t need to check the regexp part as we´ve already forced only numeric args with the above ==0...
+   
+    # check for exponentials
+    croak qq{\nThe p value must be numeric and in the range > 0 and < 1.} if ( $sig !~ /\A \d* \.? \d+ ([eE][+-]?\d+)? \z/xms || $sig <= 0 || $sig >= 1) ; 
+    #croak qq{\nThe p value must be numeric and in the range > 0 and < 1.} if ( $sig !~ /\A \d{1,7} \.? \d+ ([eE][+-]?\d+)? \z/xms || $sig <= 0 || $sig >= 1) ; 
+    #croak qq{\nThe p value must be numeric and in the range > 0 and < 1.} if ( $sig !~ /\A[01]?\.\d+([eE][+-]?\d+)?\z/xms || $sig <= 0 || $sig >= 1) ; 
+
+    $self->{significance} = $sig;
+    return;
+
+}
+=head2 set_significance
+
+Convenience method to reset significance level. Without a value it defaults to p = 0.05 to change this use set_significance. 
     
+    $anc->set_significance();
+    $anc->set_significance( 0.0005 );
+
+=cut
+
+#/ now a private method - only called by new and unload
+sub _set_verbosity {
     my ($self, $args_h_ref) = @_;
 
     croak qq{\nArguments must be passed as HASH reference.} if ( ( $args_h_ref ) && ( ref $args_h_ref ne q{HASH} ) );
@@ -74,28 +177,104 @@ sub set_verbosity {
     return;
 }
 
+sub set_input_verbosity {
+    #/ convinience method to reset output verbosity
+    my ( $self, $verb ) = @_;
+    #y don´t care about distinguishing default no arg and 0 here - unlike in set_significance - so just existince
+    $verb ||= 0;
+    croak qq{\nYou must pass set_output_verbosity 1 or 0 (without an arguement it defaults to 0).} if ( $verb !~ /\A[01]\z/xms ) ; 
+    $self->{verbosity}{input} = $verb;
+    return;
+}
+=head2 set_input_verbosity
+
+Convenience method to reset the input verbosity level. Pass it 1 for verbose and 0 or no argument to leave default
+silent state.
+
+    $anc->set_input_verbosity (1); # Turns on verbosity
+    $anc->set_input_verbosity (0);
+    $anc->set_input_verbosity ();
+
+=cut
+
+sub set_output_verbosity {
+    #/ convinience method to reset output verbosity
+    my ( $self, $verb ) = @_;
+    #y don´t care about distinguishing default no arg and 0 here - unlike in set_significance - so just existince
+    $verb ||= 0;
+    croak qq{\nYou must pass set_output_verbosity 1 or 0 (without an arguement it defaults to 0).} if ( $verb !~ /\A[01]\z/xms ) ; 
+    $self->{verbosity}{output} = $verb;
+    return;
+}
+=head2 set_output_verbosity
+
+Convinience method to reset the output verbosity level. Pass it 1 for verbose and 0 or no argument to leave default
+silent state.
+
+    $anc->set_output_verbosity (1); # Turns on verbosity
+    $anc->set_output_verbosity (0);
+    $anc->set_output_verbosity ();
+
+=cut
+
 sub load_data {
-    #my ($self, $h_ref, $verbose ) = @_;
-    #$verbose ||= 0;
-    #$verbose = $verbose eq q{verbose} ? 0 : 1;
-    
     my ($self, $h_ref) = @_;
 
-    croak qq{\nThe data must be passed as HASH reference.} if ( ( $h_ref ) && ( ref $h_ref ne q{HASH} ) );
-    croak qq{\nThe data must be passed as HASH reference pointed to by key \'data\'.} if (!exists $h_ref->{data});
-
+    $self->_pre_check($h_ref);
+    #y unpack the data
     my $data_ref = $h_ref->{data};
-    
-    croak qq{\nThe data pointed to by key \'data\' must be passed as HASH reference.} if ( ( $data_ref ) && ( ref $data_ref ne q{HASH} ) );
-    
-    #$verbose ||= 0;
-    #$verbose = $verbose eq q{verbose} ? 0 : 1;
+
+    $data_ref or croak qq{\nkey \'data\' points to nothing};
+    croak qq{\nThe data pointed to by key \'data\' must be passed as HASH reference.} if ( ref $data_ref ne q{HASH} );
     
     $self->_groups_info($data_ref);
+    
+    #/ there is no need to deep copy the data - we just use it...
     $self->_data_check($data_ref);
+
+    #y construct the array consisting off ALL the data
     $self->_all_array($data_ref);
+ 
+    #y set flag 
+    $self->{analysis_state}{load} = 1;
     return;
 }
+=head2 load_data
+    
+To load or re-load data. Pass the data as named arguement 'data' within an anonymous HASH pointing to nested HASH
+reference containing the data. Within this HASH reference each subsequent nested HASH corresponds to a separate
+individual/group. The names of these groups are arbitrary. Within each nested group HASH there must be exactly to keys.
+One called 'Y' (corresponding to the Dependent Variable that we wish to adjust using covariance) that points to an
+array ref or directly as an anonymous array of the corresponding data. The other key must be termed 'X' and corresponds 
+to the concomitant variable whose covariation will be used to adjust Y. X is also passed as an array ref/anonymous 
+array.
+    
+  $anc->load_data ( { data => { 'GroupA' => {   Y => [qw/ 29 27 31 33 32 24 16 /],      X => [qw/ 53 64 55 67 55 45 35 /], },
+                                'GroupB' => {   Y => [qw/ 39 34 20 35 57 28 32 17 /],   X => [qw/ 24 19 13 18 25 16 16 13 /], }, 
+                                'GroupC' => {   Y => [qw/ 12 21 26 17 25 9 12 /],       X => [qw/ 5 12 12 9 12 3 3 /], }, }, 
+                  } );
+
+=cut
+
+sub _pre_check {
+
+    my ($self, $h_ref) = @_;
+
+    #croak qq{\nThe data must be passed as HASH reference.} if ( ( $h_ref ) && ( ref $h_ref ne q{HASH} ) );
+    #croak qq{\nThe data must be passed as HASH reference pointed to by key \'data\'.} if (!exists $h_ref->{data});
+    #croak qq{\nYou must pass me some data} if ( !$h_ref );
+    #croak qq{\nThe data must be passed as HASH reference.} if ( ref $h_ref ne q{HASH} );
+    #croak qq{\nThe data must be passed as HASH reference pointed to by key \'data\'.} if ( !exists $h_ref->{data});
+   
+    if ( !$h_ref ) { croak qq{\nYou must pass me some data}; }
+    #elsif ( ( ref $h_ref ne q{HASH} ) || (!exists $h_ref->{data}) ) { croak qq{\nThe data must be passed as HASH
+    #elsif ( ref $h_ref ne q{HASH} ) { croak qq{\nThe data must be passed as HASH reference.}; }
+    #elsif ( !exists $h_ref->{data}) { croak qq{\nThe data must be passed as HASH reference pointed to by key \'data\'.}; }
+    elsif ( ( ref $h_ref ne q{HASH} ) || ( !exists $h_ref->{data} ) ) { croak qq{\nThe data must be passed within a HASH reference pointed to by key \'data\'.}; }
+
+    return;
+
+}
 
 sub _groups_info {
     my ($self, $h_ref ) = @_;
@@ -141,9 +320,15 @@ sub _data_check {
     print qq{\nData passed. Feeding it to Ancova object.} if $verbose;
 
     $self->{lengths} = {%group_lengths};
-
+    
+    #/ we haven´t deep copied so this is pointless!
     ##s we aren´t actually using that hash passed at all - we are copying it - that way they can use that same hash name again later - i.e. we allocate NEW memory location
+    #y point is data passed checks so we put it into object
+    
+    #y that is while we create a new higher level copy we don´t deep copy so its pointless using this syntax and not
+    #y simply $self->{data} = $h_ref - if we deep copy then we are safe from this issue - clearly T is new data...
     $self->{data} = {%{$h_ref}};
+
     return;
 }
 
@@ -187,6 +372,7 @@ sub print_data {
 
 sub unload {
     my $self = shift;
+    croak qq{\nYou have to load some data before calling this method} if ( !exists $self->{analysis_state}{load} );
     my @object_keys = keys %{$self};
     OBJECT:
     foreach (@object_keys) {
@@ -195,14 +381,16 @@ sub unload {
     }
     $self->{data} = {}; # empty h_ref - thus wipe out old data.
     $self->{significance} = 0.05;
-    $self->set_verbosity;
+    $self->_set_verbosity;
     return;
 }
+=head2 unload
 
-#sub diagnose {
-#    my $self = shift;
-#    print Dumper $self;
-#}
+To clear the object use unload.
+
+    $anc->unload;
+    
+=cut
 
 sub load_data_old {
     my ($self, $h_ref ) = @_;
@@ -217,11 +405,22 @@ sub load_data_old {
 
 sub ancova_analysis {
     my $self = shift;
+    croak qq{\nYou have to load some data before calling this method} if ( !exists $self->{analysis_state}{load} );
     $self->all_SS;
     $self->all_SC;
     $self->adjustments_for_correlation;
+
+    #y set flag
+    $self->{analysis_state}{analysis} = 1;
     return;
 }
+=head2 ancova_analysis
+    
+To perform the analysis.
+   
+    $anc->ancova_analysis;
+
+=cut
 
 sub all_SS {
     my $self = shift;
@@ -510,13 +709,15 @@ sub _analysis_covariance_with_adjusted_SS {
 }
 
 sub results {                                     
-    ##o get standard F values and generate messages
-    
-    
+ 
     # unpack rest of @_ - may go to verbose or list printing
     my @other_args = @_;
     my $self = shift @other_args;
     
+    croak qq{\nYou have to load some data before calling this method} if ( !exists $self->{analysis_state}{load} );
+    croak qq{\nYou have to run ancova_analysis before calling this method} if ( !exists $self->{analysis_state}{analysis} );
+    ##o get standard F values and generate messages
+    
     #my ( $self, $verbose ) = @_;
     #$verbose ||= 0;
     #my $self = shift;
@@ -537,12 +738,17 @@ sub results {
     my $chosen_p_val = $self->{significance};
     my $standard_F = fdistr ($df_bg_Y,$df_wg_Y_Adj,$chosen_p_val);
 
-    my $message     =   $F > $standard_F                             ?   qq{This value of F is significant at your chosen p = $chosen_p_val level. }
-                    :   $F > fdistr ($df_bg_Y,$df_wg_Y_Adj,0.01)     ?   qq{This value of F is significant at the p = 0.01 level. }
-                    :   $F > fdistr ($df_bg_Y,$df_wg_Y_Adj,0.05)     ?   qq{This value of F is significant at the p = 0.05 level. }
-                    :                                                    qq{This is not a significant value of F. } # default behaviour
-    ;   
+    #/ this approach confuses people! have it simply pass of fail at their selected p_value - it already has a default value
+#    my $message     =   $F > $standard_F                             ?   qq{This value of F is significant at your chosen p = $chosen_p_val level. }
+#                    :   $F > fdistr ($df_bg_Y,$df_wg_Y_Adj,0.01)     ?   qq{This value of F is significant at the p = 0.01 level. }
+#                    :   $F > fdistr ($df_bg_Y,$df_wg_Y_Adj,0.05)     ?   qq{This value of F is significant at the p = 0.05 level. }
+#                    :                                                    qq{This is not a significant value of F. } # default behaviour
+#    ;   
 
+    my $message = $F > $standard_F ? qq{This value of F is significant at the p = $chosen_p_val level. } :
+      qq{This is not a significant value of F at the p = $chosen_p_val level. };   
+
+      
     my $p_for_F = fprob ( $df_bg_Y, $df_wg_Y_Adj, $F ) ;    
     $self->{output}{message} = $message;
     $self->{output}{standard_F} = $standard_F;
@@ -563,6 +769,44 @@ sub results {
             STR     { $message                         }     
     );                          
 }
+=head2 results
+
+Used to access the results of the ANCOVA analysis. This method is context-dependent and will return a variety of 
+different values depending on its calling context. In VOID context prints a report to STDOUT (use 
+C<set_output_verbosity> to print more detailed report). 
+
+    # To print a short report to STDOUT
+    $anc->results();
+    # To print a detailed report set output_verbosity to 1 on object creation or using the set_output_verbosity> method.
+    $anc->set_output_verbosity(1);
+    $anc->results();
+
+
+In LIST context it either returns the full list of all relevant values of F, p, df, MS... or returns an ordered subset of the values
+depending on whether you call it without or with numbered arguments respectively (see below). 
+
+    # Calling results in LIST without arguments returns the full list of relevant values of F, p, df, MS...
+    my %hash;
+    @hash{qw($F_score, $p_value, $MS_bg, $SS_bg_Adj, $df_bg_Y, $MS_wg, $SS_wg_Adj, $df_wg_Y_Adj, $SS_total_Adj)} = $anc->results();
+    for (keys %hash) { print qq{\n$_ = $hash{$_} } };
+
+However, calling C<results> in LIST context with numbered arguments corresponding to those below returns those arguments 
+in the order passed to the method.
+
+    #      0         1        2        3          4         5        6            7              8      
+    # ($F_score, $p_value, $MS_bg, $SS_bg_Adj, $df_bg_Y, $MS_wg, $SS_wg_Adj, $df_wg_Y_Adj, $SS_total_Adj) = $anc->results(2,3,5)   
+    print qq{\n\nCalling in LIST context. The F value, p_value, MS_bg and MS_wg are: @{$anc->results(0,1,2,,5)}};
+
+In BOOLEAN context it returns true or false depending on whether the obtained F score was significant at the p_value chosen
+upon object creation or set using the C<set_significance> method (defaults to p = 0.05). 
+
+    if ($anc->results) { print qq{\nThis result is significant.} } else { print qq{\nThis result is not significant.} } 
+
+In STRING context it returns a string message about whether the obtained F score was significant at the chosen p_value. 
+    
+    print qq{\n\nCall result in string returns a message : }, ''.$anc->results;  # Prints 'This value of F is significant at your chosen .05 level'... 
+
+=cut
 
 sub _print_form {
     #my ( $self, $verbose ) = @_;
@@ -734,121 +978,12 @@ sub _return_list {
     return @returns;
 }
 
-
 1; # Magic true value required at end of module
-
 __END__
 
-=head1 NAME
-
-Statistics::Distributions::Ancova - Perl implementation of One-Way Analysis of Covariance for Independent Samples.
-
-=head1 VERSION
-
-This document describes Statistics::Distributions::Ancova version 0.03.01
-
-=head1 SYNOPSIS
-
-    use Statistics::Distributions::Ancova;
-    use strict;
-
-    # Create an Ancova object and use optional named arguments to set option. 
-    # Use significance option to set the significance level for the test - defaults to 0.05 without argument.
-    # my $anc = Statistics::Distributions::Ancova->new ( { significance => 0.005 } );
-    my $anc = Statistics::Distributions::Ancova->new ();
-    
-    # To print the data checking messages on data input to STDOUT when load_data method is called set input_verbosity to 1.
-    # To print a more detailed report to STDOUT when results method is called set output_verbosity to 1.
-    my $anc = Statistics::Distributions::Ancova->new ( { 
-      significance => 0.005, input_verbosity => 1, output_verbosity => 1 
-      } );
-
-    # Example using k=3 groups our dependent variable of interest (Y) along with covariant data for the concomitant 
-    # variable (X) used to adjust (Y) to eliminate obscuring effects of covariance.
-    my @Drug_A_Y =  ('29','27','31','33','32','24','16');
-    my @Drug_A_X = ('53','64','55','67','55','45','35');
-
-    my @Drug_B_X = ('24','19','13','18','25','16','16','13');
-    my @Drug_B_Y = ('39','34','20','35','57','28','32','17');
-
-    my @Drug_C_X = ('5','12','12','9','12','3','3');
-    my @Drug_C_Y = ('12','21','26','17','25','9','12');
-
-    # Data is sent to object as nested HASH reference. The individual group names are option, but the variable names Y 
-    # and X are compulsory.
-    my $h_ref = { 'group_A' =>  {
-                                    Y => \@Drug_A_Y,
-                                    X => \@Drug_A_X,
-                            }, 
-                'group_B' =>  { 
-                                    Y => \@Drug_B_Y,
-                                    X => \@Drug_B_X,
-                            }, 
-                'group_C' =>  { 
-                                    Y => \@Drug_C_Y,
-                                    X => \@Drug_C_X,
-                            }, 
-                };
-
-    # Feed the object the data pass data HASH reference with named argument 'data'.
-    $anc->load_data ( { data => $h_ref } );
-
-    # To clear the object use unload.
-    $anc->unload;
-    
-    # To reset the verbosity level use set_verbosity. Without a value both input and output verbosity default to 0 (no 
-    # extended messages).
-    #$anc->set_verbosity ( { input_verbosity => 1, output_verbosity => 1 } );
-    $anc->set_verbosity ();
-    
-    # Reload data.
-    $anc->load_data ( { data => $h_ref } );
-
-    # To reset significance level use set_significance. Without a value it defaults to p = 0.05 to change this use 
-    # set_significance. 
-    #$anc->set_significance();
-    $anc->set_significance( {significance => q{0.0005} } );
-
-    # perform the analysis
-    $anc->ancova_analysis;
-
-    # To print a report to STDOUT call results in VOID context.
-    $anc->results();
-
-    # Calling results method in BOOLEAN returns true or false depending on whether the obtained F score was significant 
-    # at chosen p.
-    print qq{\nIt is significant.} if ($anc->results);    
-
-    # Calling results method in STRING returns a string message about test result.
-    print qq{\n\nCall result in string returns a message : }, ''.$anc->results;         
-        
-        # in this case prints 'This value of F is significant at your chosen .05 level' 
-
-    # Calling results in LIST without arguments returns the full list of relevant values of F, p, df, MS...
-    my %hash;
-    print qq{\n\nCalling in LIST context without arguments:};
-    @hash{qw($F_score, $p_value, $MS_bg, $SS_bg_Adj, $df_bg_Y, 
-      $MS_wg, $SS_wg_Adj, $df_wg_Y_Adj, $SS_total_Adj)} = $anc->results();
-    for (keys %hash) { print qq{\n$_ = $hash{$_} } };
-
-    # Calling results in LIST with numbered arguments corresponding to those below returns those arguments in the order 
-    # passed to the method.
-    #      0         1        2        3          4         5        6            7              8      
-    # ($F_score, $p_value, $MS_bg, $SS_bg_Adj, $df_bg_Y, $MS_wg, $SS_wg_Adj, $df_wg_Y_Adj, $SS_total_Adj) = $anc->results(2,3,5)   
-    print qq{\n\nCalling in LIST context. The F value, p_value, MS_bg and MS_wg are: @{$anc->results(0,1,2,,5)}};
-
-=head1 DESCRIPTION
-
-A perl implementation of One-Way Analysis of Covariance for Independent Samples. As with paired t-test and
-repeated-measures ANOVA this test removes the obscuring effects of pre-existing individual differences among subjects.
-In cases where a substantial portion of the variability that occurs within each of the set of a dependent variable Y is 
-actually covariance with another concomitant variable X measures, this test removes the covariance with X from Y thus 
-removing a portion of the irrelevant variability of individual differences. 
-
-See http://en.wikipedia.org/wiki/Analysis_of_covariance for more info.
-
 =head1 DEPENDENCIES
 
+'version'                   => 0,
 'Statistics::Distributions' => '1.02',
 'Math::Cephes'              => '0.47', 
 'Carp'                      => '1.08', 
@@ -856,10 +991,12 @@ See http://en.wikipedia.org/wiki/Analysis_of_covariance for more info.
 'Contextual::Return'        => '0.2.1',
 'List::Util'                => '1.19', 
 
+=cut
 =head1 AUTHOR
 
 Daniel S. T. Hughes  C<< <dsth@cpan.org> >>.
 
+=cut
 =head1 LICENCE AND COPYRIGHT
 
 Copyright (c) 2009, Daniel S. T. Hughes C<< <dsth@cpan.org> >>. All rights reserved.
@@ -867,24 +1004,25 @@ Copyright (c) 2009, Daniel S. T. Hughes C<< <dsth@cpan.org> >>. All rights reser
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
+=cut
 =head1 SEE ALSO
 
 L<Statistics::Descriptive>, L<Statistics::Distributions>, L<Statistics::Distributions::Analyze>, L<Statistics::ANOVA>.
 
-
+=cut
 =head1 DISCLAIMER OF WARRANTY
 
-because this software is licensed free of charge, there is no warranty
+Because this software is licensed free of charge, there is no warranty
 for the software, to the extent permitted by applicable law. except when
 otherwise stated in writing the copyright holders and/or other parties
 provide the software "as is" without warranty of any kind, either
 expressed or implied, including, but not limited to, the implied
-warranties of merchantability and fitness for a particular purpose. the
+warranties of merchantability and fitness for a particular purpose. The
 entire risk as to the quality and performance of the software is with
 you. should the software prove defective, you assume the cost of all
 necessary servicing, repair, or correction.
 
-in no event unless required by applicable law or agreed to in writing
+In no event unless required by applicable law or agreed to in writing
 will any copyright holder, or any other party who may modify and/or
 redistribute the software as permitted by the above licence, be
 liable to you for damages, including any general, special, incidental,
